@@ -249,7 +249,6 @@ sub caseignore_appe {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -346,7 +345,6 @@ sub caseignore_cwd {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -479,7 +477,6 @@ sub caseignore_cwd_exact_match {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -607,7 +604,6 @@ sub caseignore_cwd_issue5 {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -740,7 +736,6 @@ sub caseignore_dele {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -833,7 +828,6 @@ sub caseignore_dele_issue5 {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -923,7 +917,6 @@ sub caseignore_mdtm {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -1010,7 +1003,6 @@ sub caseignore_mkd {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -1046,29 +1038,37 @@ sub caseignore_mkd {
       my $client = ProFTPD::TestSuite::FTP->new('127.0.0.1', $port);
       $client->login($setup->{user}, $setup->{passwd});
 
-      # Due to Issue #1639, ProFTPD now treats EEXIST errors for MKDIR
-      # requests as success.
-      my ($resp_code, $resp_msg) = $client->mkd('TeSt.D');
+      eval { $client->mkd('TeSt.D') };
+      unless ($@) {
+        die("MKD TeSt.D succeeded unexpectedly");
+      }
+ 
+      my $resp_code = $client->response_code();
+      my $resp_msg = $client->response_msg();
 
-      my $expected = 257;
+      my $expected = 550;
       $self->assert($expected == $resp_code,
         test_msg("Expected response code $expected, got $resp_code"));
 
-      $expected = 'Directory successfully created';
-      $self->assert(qr/$expected/, $resp_msg,
+      $expected = 'test.d: File exists';
+      $self->assert($expected eq $resp_msg,
         test_msg("Expected response message '$expected', got '$resp_msg'"));
 
-      ($resp_code, $resp_msg) = $client->xmkd('TeSt.D');
+      eval { $client->xmkd('TeSt.D') };
+      unless ($@) {
+        die("XMKD TeSt.D succeeded unexpectedly");
+      }
 
-      $expected = 257;
+      $resp_code = $client->response_code();
+      $resp_msg = $client->response_msg();
+
+      $expected = 550;
       $self->assert($expected == $resp_code,
-        test_msg("Expected response code $expected, got $resp_code"));
+        test_msg("Expected $expected, got $resp_code"));
 
-      $expected = 'Directory successfully created';
-      $self->assert(qr/$expected/, $resp_msg,
-        test_msg("Expected response message '$expected', got '$resp_msg'"));
-
-      $client->quit();
+      $expected = 'test.d: File exists';
+      $self->assert($expected eq $resp_msg,
+        test_msg("Expected '$expected', got '$resp_msg'"));
     };
     if ($@) {
       $ex = $@;
@@ -1111,7 +1111,6 @@ sub caseignore_mlsd {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -1191,7 +1190,6 @@ sub caseignore_mlst {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1277,7 +1275,6 @@ sub caseignore_retr {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1323,9 +1320,8 @@ sub caseignore_retr {
       }
 
       my $buf;
-      while ($conn->read($buf, 25) > 0) {
-      }
-      eval { $conn->close(5) };
+      $conn->read($buf, 25);
+      eval { $conn->close() };
       sleep(1);
 
       my $resp_code = $client->response_code();
@@ -1376,7 +1372,6 @@ sub caseignore_retr_issue5 {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1423,10 +1418,10 @@ sub caseignore_retr_issue5 {
 
       my $buf;
       $conn->read($buf, 25);
-      sleep(1);
-
       eval { $conn->close() };
 
+      sleep(1);
+
       my $resp_code = $client->response_code();
       my $resp_msg = $client->response_msg();
       $self->assert_transfer_ok($resp_code, $resp_msg);
@@ -1474,7 +1469,6 @@ sub caseignore_rmd {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -1574,7 +1568,6 @@ sub caseignore_rnfr {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1667,7 +1660,6 @@ sub caseignore_rnto {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'off',
 
@@ -1772,7 +1764,6 @@ sub caseignore_size {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1863,7 +1854,6 @@ sub caseignore_stat {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1951,7 +1941,6 @@ sub caseignore_stor {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -2060,7 +2049,6 @@ sub caseignore_stor_filename_with_spaces {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -2169,7 +2157,6 @@ sub caseignore_stor_issue5 {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -2270,7 +2257,6 @@ sub caseignore_list {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -2389,7 +2375,6 @@ sub caseignore_list_filename_with_spaces {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -2514,7 +2499,6 @@ sub caseignore_list_no_matches {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -2641,7 +2625,6 @@ sub caseignore_list_issue5 {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -2761,7 +2744,6 @@ sub caseignore_nlst {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -2880,7 +2862,6 @@ sub caseignore_list_extlog_var_r {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     DefaultRoot => '~',
     LogFormat => 'custom "%r"',
@@ -3026,7 +3007,6 @@ sub caseignore_site_chmod {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -3125,7 +3105,6 @@ sub caseignore_site_chmod_filename_with_spaces {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -3232,7 +3211,6 @@ sub caseignore_site_chgrp {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -3339,7 +3317,6 @@ sub caseignore_site_chgrp_filename_with_spaces {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -3439,7 +3416,6 @@ sub caseignore_cmds_cwd {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     IfModules => {
       'mod_case.c' => {
@@ -3544,7 +3520,6 @@ sub caseignore_multi_cwds_to_dst {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
