@@ -199,7 +199,6 @@ sub caseignore_sftp_realpath {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -335,7 +334,6 @@ sub caseignore_sftp_lstat {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -468,7 +466,6 @@ sub caseignore_sftp_setstat {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -604,7 +601,6 @@ sub caseignore_sftp_opendir {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -768,7 +764,6 @@ sub caseignore_sftp_stat {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -904,7 +899,6 @@ sub caseignore_sftp_readlink {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1031,7 +1025,6 @@ sub caseignore_sftp_symlink_src {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1165,7 +1158,6 @@ sub caseignore_sftp_symlink_src_issue5 {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1310,7 +1302,6 @@ sub caseignore_sftp_symlink_dst {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1454,7 +1445,6 @@ sub caseignore_sftp_symlink_dst_issue5 {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1577,7 +1567,6 @@ sub caseignore_sftp_download {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1729,7 +1718,6 @@ sub caseignore_sftp_upload {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1861,7 +1849,6 @@ sub caseignore_sftp_mkdir {
 
     AuthUserFile => $setup->{auth_user_file},
     AuthGroupFile => $setup->{auth_group_file},
-    AuthOrder => 'mod_auth_file.c',
 
     AllowOverwrite => 'on',
     AllowStoreRestart => 'on',
@@ -1929,17 +1916,20 @@ sub caseignore_sftp_mkdir {
         die("Can't use SFTP on SSH2 server: [$err_name] ($err_code) $err_str");
       }
 
-      # Due to Issue #1639, ProFTPD now treats EEXIST errors for MKDIR
-      # requests as success.
       my $res = $sftp->mkdir('TeSt.D');
-      unless ($res) {
-        my ($err_code, $err_name) = $sftp->error();
-        die("Can't mkdir TeSt.D: [$err_name] ($err_code)");
+      if ($res) {
+        die("MKDIR TeSt.D succeeded unexpectedly");
       }
 
+      my ($err_code, $err_name) = $sftp->error();
+
       $sftp = undef;
       $ssh2->disconnect();
 
+      my $expected = 'SSH_FX_FAILURE';
+      $self->assert($expected eq $err_name,
+        test_msg("Expected error '$expected', got '$err_name'"));
+
       if ($^O ne 'darwin') {
         # Avoid this check on Mac OSX, due to its default case-insensitve
         # (but case-preserving) filesystem.  Yuck.
